package SHARYANTO::Dummy::Module1;
BEGIN {
  $SHARYANTO::Dummy::Module1::VERSION = '0.01';
}

sub from_dist2 {
}

1;
# ABSTRACT: Dummy dist to test PAUSE indexing, add functions to Module1

__END__
=pod

=head1 NAME

SHARYANTO::Dummy::Module1 - Dummy dist to test PAUSE indexing, add functions to Module1

=head1 VERSION

version 0.01

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

